pub enum MigratableExecuteMsg {
    Migrate {
        admin_permit: Permit,
        migrate_to: MigrateTo,
    },
    RegisterToNotifyOnMigrationComplete {
        address: String,
        code_hash: String,
    },
}

Variants



Migrate

Fields

admin_permit: Permit

permit used to verify address executing migration is admin

migrate_to: MigrateTo

Set migration secret (using entropy for randomness), and the address of the new contract



RegisterToNotifyOnMigrationComplete

Fields

address: String
code_hash: String

Sets a contract that should be notified when this contract completes the migration process