pub enum MigratableExecuteMsg {
Migrate {
admin_permit: Permit,
migrate_to: MigrateTo,
},
RegisterToNotifyOnMigrationComplete {
address: String,
code_hash: String,
},
}Variants
Migrate
Fields

admin_permit: Permitpermit used to verify address executing migration is admin
Set migration secret (using entropy for randomness), and the address of the new contract
RegisterToNotifyOnMigrationComplete
Sets a contract that should be notified when this contract completes the migration process